==> qcs_api_client-0.24.1-py3-none-any.whl: qcs_api_client/operations/sync_from_dict/__init__.py <==
from qcs_api_client.api.account.add_group_user import sync_from_dict as add_group_user
from qcs_api_client.api.account.get_group_balance import sync_from_dict as get_group_balance
from qcs_api_client.api.account.get_group_billing_customer import sync_from_dict as get_group_billing_customer
from qcs_api_client.api.account.get_group_upcoming_billing_invoice import (
    sync_from_dict as get_group_upcoming_billing_invoice,
)
from qcs_api_client.api.account.get_user_balance import sync_from_dict as get_user_balance
from qcs_api_client.api.account.get_user_billing_customer import sync_from_dict as get_user_billing_customer
from qcs_api_client.api.account.get_user_upcoming_billing_invoice import (
    sync_from_dict as get_user_upcoming_billing_invoice,
)
from qcs_api_client.api.account.list_group_billing_invoice_lines import (
    sync_from_dict as list_group_billing_invoice_lines,
)
from qcs_api_client.api.account.list_group_billing_invoices import sync_from_dict as list_group_billing_invoices
from qcs_api_client.api.account.list_group_upcoming_billing_invoice_lines import (
    sync_from_dict as list_group_upcoming_billing_invoice_lines,
)
from qcs_api_client.api.account.list_group_users import sync_from_dict as list_group_users
from qcs_api_client.api.account.list_user_billing_invoice_lines import sync_from_dict as list_user_billing_invoice_lines
from qcs_api_client.api.account.list_user_billing_invoices import sync_from_dict as list_user_billing_invoices
from qcs_api_client.api.account.list_user_groups import sync_from_dict as list_user_groups
from qcs_api_client.api.account.list_user_upcoming_billing_invoice_lines import (
    sync_from_dict as list_user_upcoming_billing_invoice_lines,
)
from qcs_api_client.api.account.remove_group_user import sync_from_dict as remove_group_user
from qcs_api_client.api.authentication.auth_email_password_reset_token import (
    sync_from_dict as auth_email_password_reset_token,
)
from qcs_api_client.api.authentication.auth_get_user import sync_from_dict as auth_get_user
from qcs_api_client.api.authentication.auth_reset_password import sync_from_dict as auth_reset_password
from qcs_api_client.api.authentication.auth_reset_password_with_token import (
    sync_from_dict as auth_reset_password_with_token,
)
from qcs_api_client.api.client_applications.check_client_application import sync_from_dict as check_client_application
from qcs_api_client.api.client_applications.get_client_application import sync_from_dict as get_client_application
from qcs_api_client.api.client_applications.list_client_applications import sync_from_dict as list_client_applications
from qcs_api_client.api.default.get_health import sync_from_dict as get_health
from qcs_api_client.api.default.health_check import sync_from_dict as health_check
from qcs_api_client.api.default.health_check_deprecated import sync_from_dict as health_check_deprecated
from qcs_api_client.api.endpoints.create_endpoint import sync_from_dict as create_endpoint
from qcs_api_client.api.endpoints.delete_endpoint import sync_from_dict as delete_endpoint
from qcs_api_client.api.endpoints.get_default_endpoint import sync_from_dict as get_default_endpoint
from qcs_api_client.api.endpoints.get_endpoint import sync_from_dict as get_endpoint
from qcs_api_client.api.endpoints.list_endpoints import sync_from_dict as list_endpoints
from qcs_api_client.api.endpoints.restart_endpoint import sync_from_dict as restart_endpoint
from qcs_api_client.api.engagements.create_engagement import sync_from_dict as create_engagement
from qcs_api_client.api.quantum_processors.get_instruction_set_architecture import (
    sync_from_dict as get_instruction_set_architecture,
)
from qcs_api_client.api.quantum_processors.get_quantum_processor import sync_from_dict as get_quantum_processor
from qcs_api_client.api.quantum_processors.list_quantum_processor_accessors import (
    sync_from_dict as list_quantum_processor_accessors,
)
from qcs_api_client.api.quantum_processors.list_quantum_processors import sync_from_dict as list_quantum_processors
from qcs_api_client.api.reservations.create_reservation import sync_from_dict as create_reservation
from qcs_api_client.api.reservations.delete_reservation import sync_from_dict as delete_reservation
from qcs_api_client.api.reservations.find_available_reservations import sync_from_dict as find_available_reservations
from qcs_api_client.api.reservations.list_group_reservations import sync_from_dict as list_group_reservations
from qcs_api_client.api.reservations.list_reservations import sync_from_dict as list_reservations
from qcs_api_client.api.translation.get_quilt_calibrations import sync_from_dict as get_quilt_calibrations
from qcs_api_client.api.translation.translate_native_quil_to_encrypted_binary import (
    sync_from_dict as translate_native_quil_to_encrypted_binary,
)

==> qcs_api_client-0.26.4-py3-none-any.whl: qcs_api_client/operations/sync_from_dict/__init__.py <==
from qcs_api_client.api.account.activate_user import sync_from_dict as activate_user
from qcs_api_client.api.account.add_group_user import sync_from_dict as add_group_user
from qcs_api_client.api.account.dismiss_viewer_announcement import sync_from_dict as dismiss_viewer_announcement
from qcs_api_client.api.account.get_group_balance import sync_from_dict as get_group_balance
from qcs_api_client.api.account.get_group_billing_customer import sync_from_dict as get_group_billing_customer
from qcs_api_client.api.account.get_group_upcoming_billing_invoice import (
    sync_from_dict as get_group_upcoming_billing_invoice,
)
from qcs_api_client.api.account.get_user_balance import sync_from_dict as get_user_balance
from qcs_api_client.api.account.get_user_billing_customer import sync_from_dict as get_user_billing_customer
from qcs_api_client.api.account.get_user_event_billing_price import sync_from_dict as get_user_event_billing_price
from qcs_api_client.api.account.get_user_upcoming_billing_invoice import (
    sync_from_dict as get_user_upcoming_billing_invoice,
)
from qcs_api_client.api.account.get_viewer_user_onboarding_completed import (
    sync_from_dict as get_viewer_user_onboarding_completed,
)
from qcs_api_client.api.account.list_group_billing_invoice_lines import (
    sync_from_dict as list_group_billing_invoice_lines,
)
from qcs_api_client.api.account.list_group_billing_invoices import sync_from_dict as list_group_billing_invoices
from qcs_api_client.api.account.list_group_upcoming_billing_invoice_lines import (
    sync_from_dict as list_group_upcoming_billing_invoice_lines,
)
from qcs_api_client.api.account.list_group_users import sync_from_dict as list_group_users
from qcs_api_client.api.account.list_user_billing_invoice_lines import sync_from_dict as list_user_billing_invoice_lines
from qcs_api_client.api.account.list_user_billing_invoices import sync_from_dict as list_user_billing_invoices
from qcs_api_client.api.account.list_user_groups import sync_from_dict as list_user_groups
from qcs_api_client.api.account.list_user_upcoming_billing_invoice_lines import (
    sync_from_dict as list_user_upcoming_billing_invoice_lines,
)
from qcs_api_client.api.account.list_viewer_announcements import sync_from_dict as list_viewer_announcements
from qcs_api_client.api.account.put_viewer_user_onboarding_completed import (
    sync_from_dict as put_viewer_user_onboarding_completed,
)
from qcs_api_client.api.account.remove_group_user import sync_from_dict as remove_group_user
from qcs_api_client.api.account.update_viewer_user_profile import sync_from_dict as update_viewer_user_profile
from qcs_api_client.api.authentication.auth_email_password_reset_token import (
    sync_from_dict as auth_email_password_reset_token,
)
from qcs_api_client.api.authentication.auth_get_user import sync_from_dict as auth_get_user
from qcs_api_client.api.authentication.auth_reset_password import sync_from_dict as auth_reset_password
from qcs_api_client.api.authentication.auth_reset_password_with_token import (
    sync_from_dict as auth_reset_password_with_token,
)
from qcs_api_client.api.client_applications.check_client_application import sync_from_dict as check_client_application
from qcs_api_client.api.client_applications.get_client_application import sync_from_dict as get_client_application
from qcs_api_client.api.client_applications.list_client_applications import sync_from_dict as list_client_applications
from qcs_api_client.api.default.get_health import sync_from_dict as get_health
from qcs_api_client.api.default.health_check import sync_from_dict as health_check
from qcs_api_client.api.default.health_check_deprecated import sync_from_dict as health_check_deprecated
from qcs_api_client.api.endpoints.create_endpoint import sync_from_dict as create_endpoint
from qcs_api_client.api.endpoints.delete_endpoint import sync_from_dict as delete_endpoint
from qcs_api_client.api.endpoints.get_default_endpoint import sync_from_dict as get_default_endpoint
from qcs_api_client.api.endpoints.get_endpoint import sync_from_dict as get_endpoint
from qcs_api_client.api.endpoints.list_endpoints import sync_from_dict as list_endpoints
from qcs_api_client.api.endpoints.restart_endpoint import sync_from_dict as restart_endpoint
from qcs_api_client.api.engagements.create_engagement import sync_from_dict as create_engagement
from qcs_api_client.api.quantum_processors.get_instruction_set_architecture import (
    sync_from_dict as get_instruction_set_architecture,
)
from qcs_api_client.api.quantum_processors.get_quantum_processor import sync_from_dict as get_quantum_processor
from qcs_api_client.api.quantum_processors.list_instruction_set_architectures import (
    sync_from_dict as list_instruction_set_architectures,
)
from qcs_api_client.api.quantum_processors.list_quantum_processor_accessors import (
    sync_from_dict as list_quantum_processor_accessors,
)
from qcs_api_client.api.quantum_processors.list_quantum_processors import sync_from_dict as list_quantum_processors
from qcs_api_client.api.reservations.create_reservation import sync_from_dict as create_reservation
from qcs_api_client.api.reservations.delete_reservation import sync_from_dict as delete_reservation
from qcs_api_client.api.reservations.find_available_reservations import sync_from_dict as find_available_reservations
from qcs_api_client.api.reservations.get_quantum_processor_calendar import (
    sync_from_dict as get_quantum_processor_calendar,
)
from qcs_api_client.api.reservations.list_group_reservations import sync_from_dict as list_group_reservations
from qcs_api_client.api.reservations.list_reservations import sync_from_dict as list_reservations
from qcs_api_client.api.translation.get_quilt_calibrations import sync_from_dict as get_quilt_calibrations
from qcs_api_client.api.translation.translate_native_quil_to_encrypted_binary import (
    sync_from_dict as translate_native_quil_to_encrypted_binary,
)
